@@ -1,6 +1,6 @@
 # _*_ coding: utf-8 _*_
 #
-# hspylib-firebase v0.9.91
+# hspylib-firebase v0.9.93
 #
 # Package: main.firebase
 """Package initialization."""
@@ -9,7 +9,7 @@ __all__ = [
   '__classpath__', 
   '__main__', 
   'core', 
-  'entity', 
+  'domain', 
   'exception'
 ]
-__version__ = '0.9.91'
+__version__ = '0.9.93'
